@@ -3,6 +3,8 @@
 # 04/06/2020
 """ Allows user and permission settings to be configured. """
 
+# Standard library.
+from os import remove
 # Required internal class.
 from tlnetcard_python.system.administration.batch_configuration import BatchConfiguration
 
@@ -53,8 +55,8 @@ class UserManager:
             return -1
 
         # GETing system configuration and writing lines to list.
-        self._batch_object.download_system_configuration("system_config.ini")
-        with open("system_config.ini", "r") as sys_config_file:
+        self._batch_object.download_system_configuration("system_config_temp.ini")
+        with open("system_config_temp.ini", "r") as sys_config_file:
             sys_config = sys_config_file.readlines()
 
         # Parsing list for permissions code.
@@ -72,6 +74,9 @@ class UserManager:
         for i in range(0, len(permission_types)):
             user_permissions[permission_types[i]] = bool(int(permission_code_bin[i]))
 
+        # Cleaning up.
+        remove("system_config_temp.ini")
+
         return user_permissions
     def get_server_info(self):
         """ GETs information about the RADIUS server. """
@@ -175,28 +180,36 @@ class UserManager:
         permission_code_bin += str(int(callback_nas_prompt))
         permission_code_bin += str(int(call_check))
         permission_code_bin += str(int(callback_administrative))
+        permission_code_bin = permission_code_bin[::-1]
 
         # Converting binary string to integer.
         permission_code = int(permission_code_bin, 2)
 
         # GETing system configuration and writing lines to list.
-        self._batch_object.download_system_configuration("system_config.ini")
-        with open("system_config.ini", "r") as sys_config_file:
+        self._batch_object.download_system_configuration("system_config_temp.ini")
+        with open("system_config_temp.ini", "r") as sys_config_file:
             sys_config = sys_config_file.readlines()
 
         # Parsing list and adding permissions code.
         updated_sys_config = []
         for line in sys_config:
             if line.find(user_type) != -1:
-                updated_sys_config.append(user_type + " Type=" + str(permission_code))
+                updated_sys_config.append(user_type + " Type=" + str(permission_code) + "\n")
             else:
                 updated_sys_config.append(line)
 
+        # Writing updated config to file.
+        with open("system_config_temp.ini", "w") as sys_config_file:
+            sys_config_file.writelines(updated_sys_config)
+
         # Uploading updated batch configuration file.
-        self._batch_object.upload_system_configuration()
+        self._batch_object.upload_system_configuration("system_config_temp.ini")
+
+        # Cleaning up.
+        remove("system_config_temp.ini")
 
         return 0
-    def set_server_info(self, server, secret, port):
+    def set_server_info(self, server, secret, port=1812):
         """ Sets information for the RADIUS server. """
         # Generating payload.
         user_data = {
